@@ -11,8 +11,13 @@ class RecursiveAssignment(Assignment):
         )
 
     def right_side(self) -> str:
-        return self._get_map_func(get_var_name(self.source), target_cls=self.target.type)
+        return self._get_map_func(
+            get_var_name(self.source), target_cls=self.target.type, extra_str=self.extra_str()
+        )
 
-    def _get_map_func(self, name: str, target_cls: Any) -> str:
+    def extra_str(self) -> str:
+        return f'extra.get("{self.target.name}", {{}})'
+
+    def _get_map_func(self, name: str, target_cls: Any, extra_str: str) -> str:
         func_name = get_map_to_func_name(target_cls)
-        return f"{name}.{func_name}()"
+        return f"{name}.{func_name}({extra_str})"
